/*
 * [The "BSD licence"]
 * Copyright (c) 2013 Dandelion
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Dandelion nor the names of its contributors
 * may be used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.github.dandelion.webanalytics.jsp.tag;

import com.github.dandelion.core.asset.Asset;
import com.github.dandelion.core.asset.Assets;
import com.github.dandelion.jsp.tag.AssetsTag;
import com.github.dandelion.jsp.util.AssetsRender;
import com.github.dandelion.webanalytics.core.WebAnalyticsRequestContext;
import com.github.dandelion.webanalytics.core.WebanalyticsConfiguration;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;
import java.util.List;

/**
 * JSP taglib for web analytics
 */
public class WebAnalyticsTag extends TagSupport {
    private static final Logger LOG = LoggerFactory.getLogger(AssetsTag.class);

    private String provider;
    private String token;
    private boolean useAssets = true;

    public int doStartTag() throws JspException {
        String _provider = WebanalyticsConfiguration.getProvider(provider);
        String _token = WebanalyticsConfiguration.getToken(token);
        String _useAssets = WebanalyticsConfiguration.getUseAssets(useAssets);
        WebAnalyticsRequestContext
            .get(pageContext.getRequest())
            .storeValue("provider", _provider)
            .storeValue("token", _token)
            .storeValue("useAssets", _useAssets)
            .setup();
        LOG.debug("Web Analytics is set up {} as provider, with token : {}", _provider, _token);
        if(!Boolean.valueOf(_useAssets)) {
            LOG.debug("render");
            List<Asset> assets = Assets.assetsFor(_provider);
            AssetsRender.render(assets, pageContext);
        }
        return SKIP_BODY;
    }

    public String getProvider() {
        return provider;
    }

    public void setProvider(String provider) {
        this.provider = provider;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public boolean isUseAssets() {
        return useAssets;
    }

    public void setUseAssets(boolean useAssets) {
        this.useAssets = useAssets;
    }
}
